==> haskell-optparse-simple-0.0.3-61-i686.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.0.3
id: optparse-simple-0.0.3-1vNlUp4k3TmACr4OfTqGEA
key: optparse-simple-0.0.3-1vNlUp4k3TmACr4OfTqGEA
license: BSD3
copyright: 2015 FP Complete
maintainer: chrisdone@fpcomplete.com
synopsis: Simple interface to optparse-applicative
description:
    Simple interface to optparse-applicative
category: Options
author: FP Complete
exposed: True
indefinite: False
exposed-modules:
    Options.Applicative.Simple
abi: 2c31543656838a79a236bfe5a1823a7b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/optparse-simple-0.0.3
hs-libraries: HSoptparse-simple-0.0.3-1vNlUp4k3TmACr4OfTqGEA
depends:
    base-4.10.0.0 template-haskell-2.12.0.0 transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=5e5914ac8ea41e5f3ffe60c10fb3d810
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.0.3-62-i686.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.0.3
id: optparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
key: optparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
license: BSD3
copyright: 2015 FP Complete
maintainer: chrisdone@fpcomplete.com
synopsis: Simple interface to optparse-applicative
description:
    Simple interface to optparse-applicative
category: Options
author: FP Complete
exposed: True
indefinite: False
exposed-modules:
    Options.Applicative.Simple
abi: dc9716213e3a067211468f478d48ff71
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/optparse-simple-0.0.3
hs-libraries: HSoptparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
depends:
    base-4.10.0.0 template-haskell-2.12.0.0 transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    either-4.5-LYT0d6MLKlX83NrOtw2Pp2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=5e5914ac8ea41e5f3ffe60c10fb3d810
             either-4.5-LYT0d6MLKlX83NrOtw2Pp2=7f1a11e1c3d8093dc62036c3f833d6de
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
